@@ -4,5 +4,5 @@ from .shufflenet_v1 import ShuffleNetV1, shufflenetv1
 
 
 __all__ = [ 'ResNet', 'ResNetV1d',
-    'ShuffleNetV1'
+    'ShuffleNetV1','resnet50','resnet18','shufflenetv1'
 ]
