@@ -63,7 +63,7 @@ def _resnet(arch, depth, pretrained, progress, **kwargs):
     if pretrained:
         state_dict = load_state_dict_from_url(model_urls[arch],
                                               progress=progress)
-        model.load_state_dict(state_dict)
+        model.load_state_dict(state_dict["state_dict"])
     # if pretrained:
     #     url_params=model_url_params[arch]
     #     state_dict = load_state_dict_from_google_drive(url_params[0],url_params[1],
